@@ -78,7 +78,6 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_TEXTURE_CLAMPING),
     MAKE_ENTRY(NV_CTRL_FSAA_APPLICATION_CONTROLLED),
     MAKE_ENTRY(NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED),
-    MAKE_ENTRY(NV_CTRL_IMAGE_SHARPENING),
     MAKE_ENTRY(NV_CTRL_GPU_CORE_TEMPERATURE),
     MAKE_ENTRY(NV_CTRL_GPU_CORE_THRESHOLD),
     MAKE_ENTRY(NV_CTRL_GPU_DEFAULT_CORE_THRESHOLD),
@@ -130,7 +129,6 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_PIXMAP_CACHE_ROUNDING_SIZE_KB),
     MAKE_ENTRY(NV_CTRL_PCI_ID),
     MAKE_ENTRY(NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE),
-    MAKE_ENTRY(NV_CTRL_IMAGE_SHARPENING_DEFAULT),
     MAKE_ENTRY(NV_CTRL_PCI_DOMAIN),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION),
     MAKE_ENTRY(NV_CTRL_GPU_COOLER_MANUAL_CONTROL),
